super_families.get_hypotheses_at_level: Method for Super Family Hypotheses Trees

Description Usage Arguments Details Value Examples

View source: R/super_families.get_hypotheses_at_level.R

Description

This function returns the hypotheses at a given level.

Usage

1
super_families.get_hypotheses_at_level(super_families, level = 1)

Arguments

super_families

Hypotheses tree of type data.tree::Node.

level

Level of the hypotheses within the tree.

Details

The function super_families.get_hypotheses_at_level translates nodes$level of all nodes in super_families to the corresponding hypotheses level. For all nodes the attribute "hypothesis_level" is added or updated.

Value

A list of nodes containing all hypotheses at the given level.

Examples

1
2
3
4
5
6
7
super_families <- Node$new("H31")
super_families$AddChild("H21")$AddChild("H11")$AddSibling("H12")
super_families$AddChild("H13")

super_families.get_hypotheses_at_level(super_families)

print(super_families, "level", "hypothesis_level")

WIAS-BERLIN/hierarchicalFDR documentation built on Dec. 30, 2019, 11:49 p.m.